==> agr-center-api-3.0.0-CLOUD-DEV-20220928.034119-44-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrMainChngDetailBo.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2022-09-22 13:18
 **/
@Data
public class AgrMainChngDetailBo implements Serializable {
	private static final long serialVersionUID =  -3181809909764473125L;

	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保周期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保周期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Long whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 编制人单位
	 */
	private String createOrgId;
	/**
	 * 编制人单位名称
	 */
	private Long createOrgName;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.1.0-CLOUD-DEV-20230727.090604-44-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrMainChngDetailBo.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrMainChngDetailBo implements Serializable {
	private static final long serialVersionUID =  7168012966803344244L;

	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保周期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保周期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 是否商城铺货标识
	 */
	private String whetherStorePlanStr;
	/**
	 * 是否有明细标识
	 */
	private String whetherHaveItemStr;

	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 编制人单位
	 */
	private String createOrgId;
	/**
	 * 编制人单位名称
	 */
	private Long createOrgName;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议模式转义
	 */
	private String agrModeStr;
	/**
	 * 协议分类转义
	 */
	private String agrTypeStr;
	/**
	 * 协议价格类型转义
	 */
	private String agrPriceTypeStr;
	/**
	 * 协议来源转义
	 */
	private String agrSrcStr;
	/**
	 * 交易模式转义
	 */
	private String tradeModeStr;
	/**
	 * 铺货方式转义
	 */
	private String vendorModeStr;
	/**
	 * 是否配送转义
	 */
	private String whetherDispatchStr;
	/**
	 * 是否分配转义
	 */
	private String whetherAssignStr;
	/**
	 * 应用范围类型转义
	 */
	private String scopeTypeStr;
	/**
	 * 调价机制转义
	 */
	private String adjustPriceStr;
	/**
	 * 采购类别转义
	 */
	private String agreementVarietyStr;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String expand1;
	/**
	 * 扩展字段2
	 */
	private String expand2;
	/**
	 * 扩展字段3
	 */
	private String expand3;
	/**
	 * 扩展字段4
	 */
	private String expand4;
	/**
	 * 扩展字段5
	 */
	private String expand5;
	/**
	 * 扩展字段6
	 */
	private String expand6;
	/**
	 * 扩展字段7
	 */
	private String expand7;
	/**
	 * 扩展字段8
	 */
	private String expand8;
	/**
	 * 扩展字段9
	 */
	private String expand9;
	/**
	 * 扩展json
	 */
	private String expandJson;
	/**
	 * 排序
	 */
	private String orderBy;

}
